import * as pulumi from "@pulumi/pulumi";
import * as pulumiKubernetes from "@pulumi/kubernetes";
export declare class Bastion extends pulumi.ComponentResource {
    /**
     * Returns true if the given object is an instance of Bastion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Bastion;
    /**
     * The name of the kubernetes deployment that contains the tailscale bastion
     */
    readonly deploymentName: pulumi.Output<string>;
    /**
     * Create a Bastion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: BastionArgs, opts?: pulumi.ComponentResourceOptions);
}
/**
 * The set of arguments for constructing a Bastion resource.
 */
export interface BastionArgs {
    /**
     * Whether we should create a new namespace.
     */
    createNamespace: boolean;
    /**
     * Whether the bastion should be highly available.
     */
    highAvailability: pulumi.Input<boolean>;
    /**
     * The bucket resource.
     */
    namespace?: pulumi.Input<pulumiKubernetes.core.v1.Namespace>;
    /**
     * The routes to advertise to tailscale. This is likely the Pod and Service CIDR.
     */
    routes: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags to apply to the tailnet device andauth key. This tag should be added to your oauth key and ACL.
     */
    tailscaleTags: pulumi.Input<pulumi.Input<string>[]>;
}
